pub struct Client { /* private fields */ }Expand description
Client for Agent Registry
Client for invoking operations on Agent Registry. Each operation on Agent Registry is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_agentregistry::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_agentregistry::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the ListDiscoverableRegistryRecords operation has
a Client::list_discoverable_registry_records, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.list_discoverable_registry_records()
.registry_id("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn batch_get_discoverable_registry_record(
&self,
) -> BatchGetDiscoverableRegistryRecordFluentBuilder
pub fn batch_get_discoverable_registry_record( &self, ) -> BatchGetDiscoverableRegistryRecordFluentBuilder
Constructs a fluent builder for the BatchGetDiscoverableRegistryRecord operation.
- The fluent builder is configurable:
entries(RegistryRecordsEntry)/set_entries(Option<Vec::<RegistryRecordsEntry>>):
required: trueThe registry-scoped groups of record IDs to retrieve. Currently, you can specify exactly one entry.
- On success, responds with
BatchGetDiscoverableRegistryRecordOutputwith field(s):registry_records(Vec::<RegistryRecordSummary>):The records that were successfully retrieved. Each record correlates to the request by its
recordId.errors(Vec::<BatchGetDiscoverableRegistryRecordError>):The per-record errors for records that could not be retrieved. This list is empty when all requested records were returned.
- On failure, responds with
SdkError<BatchGetDiscoverableRegistryRecordError>
Sourceimpl Client
impl Client
Sourcepub fn list_discoverable_registry_records(
&self,
) -> ListDiscoverableRegistryRecordsFluentBuilder
pub fn list_discoverable_registry_records( &self, ) -> ListDiscoverableRegistryRecordsFluentBuilder
Constructs a fluent builder for the ListDiscoverableRegistryRecords operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
registry_id(impl Into<String>)/set_registry_id(Option<String>):
required: trueRegistry identifier that accepts either ARN or ID format
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of records to return in a single page. Valid values are 1 through 100.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falseThe pagination token returned by a previous request. Use this value to retrieve the next page of results.
filters(RegistryRecordFilter)/set_filters(Option<Vec::<RegistryRecordFilter>>):
required: falseThe filters to apply to the discoverable registry record list.
- On success, responds with
ListDiscoverableRegistryRecordsOutputwith field(s):registry_records(Vec::<DiscoverableRegistryRecordSummary>):The page of discoverable registry record summaries.
next_token(Option<String>):The pagination token to pass to a subsequent request to retrieve the next page of results. This field is absent when there are no more results.
- On failure, responds with
SdkError<ListDiscoverableRegistryRecordsError>
Sourceimpl Client
impl Client
Sourcepub fn search_discoverable_registry_records(
&self,
) -> SearchDiscoverableRegistryRecordsFluentBuilder
pub fn search_discoverable_registry_records( &self, ) -> SearchDiscoverableRegistryRecordsFluentBuilder
Constructs a fluent builder for the SearchDiscoverableRegistryRecords operation.
- The fluent builder is configurable:
search_query(impl Into<String>)/set_search_query(Option<String>):
required: trueThe natural language query to search for matching registry records.
registry_ids(impl Into<String>)/set_registry_ids(Option<Vec::<String>>):
required: trueThe registry identifiers to search within. Currently, you must specify exactly one registry identifier. You can provide either the full Amazon Web Services Resource Name (ARN) or the registry ID.
max_results(i32)/set_max_results(Option<i32>):
required: falseThe maximum number of results to return. Valid values are 1 through 20. The default value is 10.
filters(Document)/set_filters(Option<Document>):
required: falseAn optional structured JSON metadata filter that narrows the search results. Supports the field-level operators
$eq,$ne, and$in, and the logical operators$andand$oron filterable fields.
- On success, responds with
SearchDiscoverableRegistryRecordsOutputwith field(s):registry_records(Vec::<RegistryRecordSummary>):The registry records that match the search query, ordered by relevance.
- On failure, responds with
SdkError<SearchDiscoverableRegistryRecordsError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.